diff -ur nagios-3.0.6/html/docs/objectinheritance.html nagios-3.0.6.with_check_command_override/html/docs/objectinheritance.html
--- nagios-3.0.6/html/docs/objectinheritance.html	2008-12-17 01:19:55.000000000 +0800
+++ nagios-3.0.6.with_check_command_override/html/docs/objectinheritance.html	2009-01-09 10:10:41.000000000 +0800
@@ -445,6 +445,47 @@
 </pre>
 
 
+<a name="importantvalues"></a>
+<p>
+<strong><u>Important values</u></strong>
+</p>
+
+<p>
+Service templates can make use of a special rule which gives precedence to their check_command value. If the check_command is prefixed with an exclamation mark (!), then the template's check_command is marked as important and will be used over the check_command defined for the service.
+</p>
+
+<p>
+Why is this useful? Mainly when setting a different check_command for distributed systems. You may want to set a freshness threshold and a check_command that forces the service into a failed state, but this doesn't work with the normal templating system. Using this <i>important</i> flag allows the custom check_command to be written, but a general distributed template can be used to overrule the check_command when used on a central Nagios server.
+</p>
+
+<p>
+For instance:
+</p>
+
+<pre>
+# On master
+define host{
+	name			service-distributed
+	register		0
+	active_checks_enabled	0
+	check_freshness		1
+	check_command		<font color="red">!set_to_stale</font>
+	}
+# On slave
+define host{
+	name			service-distributed
+	register		0
+	active_checks_enabled	1
+	}
+# Server configuration, used by master and slave
+define host{
+	host_name 		host1
+	check_command		check_http...
+	use			service-distributed
+	...
+	}
+</pre>
+
 <a name="multiple_templates"></a>
 <p>
 <strong><u>Multiple Inheritance Sources</u></strong>
diff -ur nagios-3.0.6/xdata/xodtemplate.c nagios-3.0.6.with_check_command_override/xdata/xodtemplate.c
--- nagios-3.0.6/xdata/xodtemplate.c	2008-12-17 01:20:05.000000000 +0800
+++ nagios-3.0.6.with_check_command_override/xdata/xodtemplate.c	2009-01-09 09:46:30.000000000 +0800
@@ -1607,6 +1607,7 @@
 		new_service->have_service_groups=FALSE;
 		new_service->check_command=NULL;
 		new_service->have_check_command=FALSE;
+		new_service->have_important_check_command=FALSE;
 		new_service->check_timeperiod_command=NULL;
 		new_service->have_check_timeperiod_command=FALSE;
 		new_service->check_period=NULL;
@@ -3823,7 +3824,13 @@
 		        }
 		else if(!strcmp(variable,"check_command")){
 			if(strcmp(value,XODTEMPLATE_NULL)){
-				if((temp_service->check_command=(char *)strdup(value))==NULL)
+				if(value[0] == '!') {
+					temp_service->have_important_check_command=TRUE;
+					temp_ptr=value+1;
+					}
+				else
+					temp_ptr=value;
+				if((temp_service->check_command=(char *)strdup(temp_ptr))==NULL)
 					result=ERROR;
 			        }
 			temp_service->have_check_command=TRUE;
@@ -8062,11 +8069,17 @@
 		xodtemplate_get_inherited_string(&template_service->have_contact_groups,&template_service->contact_groups,&this_service->have_contact_groups,&this_service->contact_groups);
 		xodtemplate_get_inherited_string(&template_service->have_contacts,&template_service->contacts,&this_service->have_contacts,&this_service->contacts);
 
-		if(this_service->have_check_command==FALSE && template_service->have_check_command==TRUE){
-			if(this_service->check_command==NULL && template_service->check_command!=NULL)
-				this_service->check_command=(char *)strdup(template_service->check_command);
-			this_service->have_check_command=TRUE;
-		        }
+		if(template_service->have_check_command==TRUE){
+			if(template_service->have_important_check_command==TRUE){
+				my_free(this_service->check_command);
+				this_service->have_check_command=FALSE;
+				}
+			if(this_service->have_check_command==FALSE){
+				if(this_service->check_command==NULL && template_service->check_command!=NULL)
+					this_service->check_command=(char *)strdup(template_service->check_command);
+				this_service->have_check_command=TRUE;
+				}
+			}
 		if(this_service->have_check_timeperiod_command==FALSE && template_service->have_check_timeperiod_command==TRUE){
 			if(this_service->check_timeperiod_command==NULL && template_service->check_timeperiod_command!=NULL)
 				this_service->check_timeperiod_command=(char *)strdup(template_service->check_timeperiod_command);
diff -ur nagios-3.0.6/xdata/xodtemplate.h nagios-3.0.6.with_check_command_override/xdata/xodtemplate.h
--- nagios-3.0.6/xdata/xodtemplate.h	2008-12-17 01:20:05.000000000 +0800
+++ nagios-3.0.6.with_check_command_override/xdata/xodtemplate.h	2009-01-09 09:04:07.000000000 +0800
@@ -431,6 +431,7 @@
 	int        have_hostgroup_name;
 	int        have_service_groups;
 	int        have_check_command;
+	int        have_important_check_command;
 	int        have_check_timeperiod_command;
 	int        have_check_period;
 	int        have_event_handler;
